summaryrefslogtreecommitdiff
path: root/libnetwork/service_linux.go
diff options
context:
space:
mode:
authorJosh Soref <jsoref@users.noreply.github.com>2017-05-22 02:25:52 +0000
committerFlavio Crisciani <flavio.crisciani@docker.com>2018-07-12 12:54:44 -0700
commita06f1b2c4e246ef759996099801f55d0c8459cd1 (patch)
treefd8ea9228f0c6a83711237e7bcee2278c514c74c /libnetwork/service_linux.go
parent9db90d27ed3886a54c20708c1a3c2f89cd6a2c4a (diff)
downloaddocker-a06f1b2c4e246ef759996099801f55d0c8459cd1.tar.gz
Spelling fixes
* addresses * assigned * at least * attachments * auxiliary * available * cleanup * communicate * communications * configuration * connection * connectivity * destination * encountered * endpoint * example * existing * expansion * expected * external * forwarded * gateway * implementations * implemented * initialize * internally * loses * message * network * occurred * operational * origin * overlapping * reaper * redirector * release * representation * resolver * retrieve * returns * sanbdox * sequence * succesful * synchronizing * update * validates Signed-off-by: Josh Soref <jsoref@gmail.com>
Diffstat (limited to 'libnetwork/service_linux.go')
-rw-r--r--libnetwork/service_linux.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/libnetwork/service_linux.go b/libnetwork/service_linux.go
index 3ffa60719c..a97d24b59e 100644
--- a/libnetwork/service_linux.go
+++ b/libnetwork/service_linux.go
@@ -27,7 +27,7 @@ import (
func init() {
reexec.Register("fwmarker", fwMarker)
- reexec.Register("redirecter", redirecter)
+ reexec.Register("redirector", redirector)
}
// Populate all loadbalancers on the network that the passed endpoint
@@ -431,7 +431,7 @@ func programIngress(gwIP net.IP, ingressPorts []*PortConfig, isDelete bool) erro
// DOCKER-USER so the user is able to filter packet first.
// The second rule should be jump to INGRESS-CHAIN.
// This chain has the rules to allow access to the published ports for swarm tasks
-// from local bridge networks and docker_gwbridge (ie:taks on other swarm netwroks)
+// from local bridge networks and docker_gwbridge (ie:taks on other swarm networks)
func arrangeIngressFilterRule() {
if iptables.ExistChain(ingressChain, iptables.Filter) {
if iptables.Exists(iptables.Filter, "FORWARD", "-j", ingressChain) {
@@ -668,7 +668,7 @@ func addRedirectRules(path string, eIP *net.IPNet, ingressPorts []*PortConfig) e
cmd := &exec.Cmd{
Path: reexec.Self(),
- Args: append([]string{"redirecter"}, path, eIP.String(), ingressPortsFile),
+ Args: append([]string{"redirector"}, path, eIP.String(), ingressPortsFile),
Stdout: os.Stdout,
Stderr: os.Stderr,
}
@@ -680,8 +680,8 @@ func addRedirectRules(path string, eIP *net.IPNet, ingressPorts []*PortConfig) e
return nil
}
-// Redirecter reexec function.
-func redirecter() {
+// Redirector reexec function.
+func redirector() {
runtime.LockOSThread()
defer runtime.UnlockOSThread()